<?php

namespace Tests\Feature;

use App\Models\Post;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Tests\TestCase;

class BlogSampleTest extends TestCase
{
    use RefreshDatabase;

    public function testPostsIndex()
    {
        Post::create([
            'title' => 'title1',
            'contents' => 'contents1'
        ]);
        $response = $this->get('/posts')->getContent();
        $titles = self::xpathQuery('//div[@style]/div[1]', $response);
        $this->assertEquals(1, count($titles));
        $this->assertEquals('title1', $titles[0]->nodeValue);
        $contents = self::xpathQuery('//div[@style]/div[2]', $response);
        $this->assertEquals(1, count($contents));
        $this->assertEquals('contents1', $contents[0]->nodeValue);
    }

    public function testPostCreateRedirect()
    {
        $response = $this->post(
            '/post/store',
            [
                'title' => 'post1',
                'contents' => 'content1'
            ]
        );
        $response->assertRedirect('/post/show/1');
    }

    private static function xpathQuery(string $query, string $html): \DOMNodeList
    {
        $libxmlUseInternalErrors = libxml_use_internal_errors(true);
        if (empty($query) || empty($html)) {
            return new \DOMNodeList();
        }
        $xpath = self::htmlToDomXPath($html);
        $results = $xpath->query($query);
        libxml_use_internal_errors($libxmlUseInternalErrors);

        return $results;
    }

    private static function htmlToDomXPath(string $html): \DomXPath
    {
        $dom = new \DomDocument();
        $dom->loadHTML('<?xml encoding=\'utf-8\'?>' . $html);
        $xpath = new \DomXPath($dom);

        return $xpath;
    }
}
